==> 1.0.0.tar.gz: lib/src/lists/ParameterTypeList.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../sub_types/ParameterTypes.dart';

/*
<parameterTypeList> ::= '(' ')'
| '(' <normalParameterTypes> ',' <optionalParameterTypes> ')'
| '(' <normalParameterTypes> ','? ')'
| '(' <optionalParameterTypes> ')'

See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
Page 176
*/

class ParameterTypeList extends ParserType {
  int caseNum;
  NormalParameterTypes normalParameterTypes;
  OptionalParamterTypes optionalParamterTypes;
  bool hasComma;

  ParameterTypeList(Lexer lexer) {
    hasComma = false;
    int attempt, maxAttempts = 4;
    int snapShot = lexer.currentIndex;
    for (attempt = 0; attempt < maxAttempts; ++attempt) {
      try {
        switch (attempt) {
          case 0: _case0(lexer); break;
          case 1: _case1(lexer); break;
          case 2: _case2(lexer); break;
          case 3: _case3(lexer); break;
        }

        break;
      }
      on WrongTokenType {
        lexer.setPos(snapShot);
      }
    }

    if (attempt == maxAttempts)
      throw WrongTokenType('Tried all options in ParameterTypeList: ALL FAILED');
  }
  
  /* '(' ')' */
  void _case0(Lexer lexer) {
    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();
    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();
    caseNum = 0;
  }
  
  /* '(' <normalParameterTypes> ',' <optionalParameterTypes> ')' */
  void _case1(Lexer lexer) {
    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();

    normalParameterTypes = NormalParameterTypes(lexer);

    checkType(lexer, TType.COMMA);
    lexer.advance();

    optionalParamterTypes = OptionalParamterTypes(lexer);

    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();
    caseNum = 1;
  }
  
  /* '(' <normalParameterTypes> ','? ')' */
  void _case2(Lexer lexer) {
    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();

    normalParameterTypes = NormalParameterTypes(lexer);

    if (isType(lexer, TType.COMMA)) {
      hasComma = true;
      lexer.advance();
    }

    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();
    caseNum = 2;
  }
  
  /* '(' <optionalParameterTypes> ')' */
  void _case3(Lexer lexer) {
    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();

    optionalParamterTypes = OptionalParamterTypes(lexer);

    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();
    caseNum = 3;
  }
  
  String toString() {
    switch (caseNum) {
      case 0: return ' ()'; break;
      case 1: return ' ($normalParameterTypes, $optionalParamterTypes)'; break;
      case 2: return ' ($normalParameterTypes' + (hasComma ? ',' : '') + ')'; break;
      case 3: return ' ($optionalParamterTypes)'; break;
    }
    return '';
  }

}

==> 1.1.1.tar.gz: lib/src/lists/ParameterTypeList.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../sub_types/ParameterTypes.dart';

/// <parameterTypeList> ::= '(' ')'
/// | '(' <normalParameterTypes> ',' <optionalParameterTypes> ')'
/// | '(' <normalParameterTypes> ','? ')'
/// | '(' <optionalParameterTypes> ')'
///
/// See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
/// Page 176

class ParameterTypeList extends ParserType {
  int caseNum;
  NormalParameterTypes normalParameterTypes;
  OptionalParamterTypes optionalParamterTypes;
  bool hasComma;

  ParameterTypeList(Lexer lexer) {
    hasComma = false;
    int attempt, maxAttempts = 4;
    int snapShot = lexer.currentIndex;
    for (attempt = 0; attempt < maxAttempts; ++attempt) {
      try {
        switch (attempt) {
          case 0:
            _case0(lexer);
            break;
          case 1:
            _case1(lexer);
            break;
          case 2:
            _case2(lexer);
            break;
          case 3:
            _case3(lexer);
            break;
        }

        break;
      } on WrongTokenType {
        lexer.setPos(snapShot);
      }
    }

    if (attempt == maxAttempts) {
      throw WrongTokenType(
          'Tried all options in ParameterTypeList: ALL FAILED');
    }
  }

  /// '(' ')'
  void _case0(Lexer lexer) {
    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();
    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();
    caseNum = 0;
  }

  /// '(' <normalParameterTypes> ',' <optionalParameterTypes> ')'
  void _case1(Lexer lexer) {
    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();

    normalParameterTypes = NormalParameterTypes(lexer);

    checkType(lexer, TType.COMMA);
    lexer.advance();

    optionalParamterTypes = OptionalParamterTypes(lexer);

    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();
    caseNum = 1;
  }

  /// '(' <normalParameterTypes> ','? ')'
  void _case2(Lexer lexer) {
    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();

    normalParameterTypes = NormalParameterTypes(lexer);

    if (isType(lexer, TType.COMMA)) {
      hasComma = true;
      lexer.advance();
    }

    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();
    caseNum = 2;
  }

  /// '(' <optionalParameterTypes> ')'
  void _case3(Lexer lexer) {
    checkType(lexer, TType.LEFT_PAREN);
    lexer.advance();

    optionalParamterTypes = OptionalParamterTypes(lexer);

    checkType(lexer, TType.RIGHT_PAREN);
    lexer.advance();
    caseNum = 3;
  }

  String toString() {
    switch (caseNum) {
      case 0:
        return ' ()';
        break;
      case 1:
        return ' ($normalParameterTypes, $optionalParamterTypes)';
        break;
      case 2:
        return ' ($normalParameterTypes' + (hasComma ? ',' : '') + ')';
        break;
      case 3:
        return ' ($optionalParamterTypes)';
        break;
    }
    return '';
  }
}
